from django.contrib.auth.models import User

class LoginAsBackend(object):
    def authenticate(self, from_user, to_username):
        if not from_user.is_superuser:
            return None
        try:
            user = User.objects.get(username=to_username)
        except User.DoesNotExist:
            return None
        return user

    def get_user(self, user_id):
        try:
            return User.objects.get(pk=user_id)
        except User.DoesNotExist:
            return None


from django.conf import settings
from django.core.exceptions import ImproperlyConfigured

if not 'login_as.auth_backend.LoginAsBackend' in settings.AUTHENTICATION_BACKENDS:
    raise ImproperlyConfigured('django-login-as requires the login_as.auth_backend.LoginAsBackend')


from setuptools import setup, find_packages

version = __import__('login_as').__version__

setup(
    name = 'django-login-as',
    version = version,
    description = 'Django Login As any user',
    author = 'Jonas Obrist',
    author_email = 'jonas.obrist@divio.ch',
    url = 'http://github.com/ojii/django-login-as',
    packages = find_packages(),
    package_data={
        'login_as': [
            'templates/login_as/*.html',
        ]
    },
    zip_safe=False,
)


from django.shortcuts import render_to_response, get_object_or_404
from django.contrib.auth import authenticate, login as auth_login
from django.contrib.auth.models import User
from django.http import HttpResponseRedirect, Http404

def chooser(request):
    if not request.user.is_superuser:
        raise Http404
    return render_to_response('login_as/chooser.html',
        {'users': User.objects.all().order_by('username')})

def login(request, username):
    if not request.user.is_superuser:
        raise Http404
    authed = authenticate(from_user=request.user, to_username=username)
    if not authed:
        raise Http404
    auth_login(request, authed)
    return HttpResponseRedirect('/')